<template>
  <NutForm
    :model-value="form"
    ref="formRef"
    :rules="rules"
    label-position="top"
    class="order-bill-recharge electric"
  >
    <NutFormItem label="缴费户号" class="bole-form-item" prop="gasAccount" required>
      <NutInput
        v-model.trim="form.gasAccount"
        class="bole-input-text"
        placeholder="请输入缴费户号"
        type="text"
        max-length="13"
      />
    </NutFormItem>
    <slot></slot>
  </NutForm>
</template>

<script setup lang="ts">
import { Form as NutForm, FormItem as NutFormItem, Input as NutInput } from '@nutui/nutui-taro';
import { FormRules } from '@nutui/nutui-taro/dist/types/__VUE/form/types';
import { reactive, ref, computed, watch } from 'vue';
import { useGetGasParValue } from '../../hooks';

defineOptions({
  name: 'GasBillRechargeBaseForm',
});

const form = defineModel<{
  province: string;
  city: string;
  gasAccount: string;
}>('form');

const { gasParValueList } = useGetGasParValue();

const rules = reactive<FormRules>({
  province: [{ required: true, message: '请选择所在区域' }],
  city: [{ required: true, message: '请选择所在城市' }],
  gasAccount: [{ required: true, message: '请输入缴费户号', regex: /^\d{13}$/ }],
});

const formRef = ref<any>(null);

defineExpose({
  validate: computed(() => formRef.value.validate),
});
</script>
